@@ -30,25 +30,68 @@ func ordinal(i int) string {
 // https://docs.github.com/en/actions/writing-workflows/choosing-what-your-workflow-does/evaluate-expressions-in-workflows-and-actions#format
 func parseFormatFuncSpecifiers(f string, n int) map[int]struct{} {
 	ret := make(map[int]struct{}, n)
-	start := -1
+
+	const none int = -1
+	start, end := none, none
+
 	for i, r := range f {
-		if r == '{' {
-			if start == i {
-				start = -1 // When the '{' is escaped like '{{'
-			} else {
-				start = i + 1 // `+ 1` because `i` points char '{'
+		// Before specifier
+		if start == none {
+			if r == '{' {
+				// Opening brace
+				start = i + 1
 			}
-		} else if start >= 0 {
-			if '0' <= r && r <= '9' {
-				continue
-			}
-			if r == '}' && start < i {
-				i, _ := strconv.Atoi(f[start:i])
-				ret[i] = struct{}{}
-			}
-			start = -1 // Done
+			continue
 		}
+
+		// Inside specifier
+		if end == none {
+			if r == '{' && i == start {
+				// Escaped '{'
+				start = none
+			} else if r == '}' {
+				if i == start {
+					// Empty specifier '{}'
+					start = none
+				} else {
+					// Closing brace.
+					end = i
+				}
+			} else if !('0' <= r && r <= '9') {
+				if r == '{' {
+					start = i + 1
+				} else {
+					start = none
+				}
+			}
+			continue
+		}
+
+		// After specifier
+		if r == '}' {
+			// Parsing specifier needs to be delayed while '}' continues.
+			continue
+		}
+		if (i-end)%2 == 1 {
+			// Odd number of closing braces means the specifier closed. For example '{0}}}' contains
+			// a specifier but '{0}}}}' doesn't.
+			v, _ := strconv.Atoi(f[start:end])
+			ret[v] = struct{}{}
+		}
+		if r == '{' {
+			start = i + 1
+		} else {
+			start = none
+		}
+		end = none
 	}
+
+	// When the input ends while '}' continues at end of specifier
+	if start > none && end > none && (len(f)-end)%2 == 1 {
+		v, _ := strconv.Atoi(f[start:end])
+		ret[v] = struct{}{}
+	}
+
 	return ret
 }
 
@@ -67,6 +110,8 @@ type FuncSignature struct {
 	// true, it means that the last type of params might be specified multiple times (including zero
 	// times). Setting true implies length of Params is more than 0.
 	VariableLengthParams bool
+	// IsConstFunc is true when the function returns a constant when all parameters are constants.
+	IsConstFunc bool
 }
 
 func (sig *FuncSignature) String() string {
@@ -93,6 +138,7 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 				StringType{},
 				StringType{},
 			},
+			IsConstFunc: true,
 		},
 		{
 			Name: "contains",
@@ -101,39 +147,37 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 				&ArrayType{Elem: AnyType{}},
 				AnyType{},
 			},
+			IsConstFunc: true,
 		},
 	},
-	"startswith": {
-		{
-			Name: "startsWith",
-			Ret:  BoolType{},
-			Params: []ExprType{
-				StringType{},
-				StringType{},
-			},
+	"startswith": {{
+		Name: "startsWith",
+		Ret:  BoolType{},
+		Params: []ExprType{
+			StringType{},
+			StringType{},
 		},
-	},
-	"endswith": {
-		{
-			Name: "endsWith",
-			Ret:  BoolType{},
-			Params: []ExprType{
-				StringType{},
-				StringType{},
-			},
+		IsConstFunc: true,
+	}},
+	"endswith": {{
+		Name: "endsWith",
+		Ret:  BoolType{},
+		Params: []ExprType{
+			StringType{},
+			StringType{},
 		},
-	},
-	"format": {
-		{
-			Name: "format",
-			Ret:  StringType{},
-			Params: []ExprType{
-				StringType{},
-				AnyType{}, // variable length
-			},
-			VariableLengthParams: true,
+		IsConstFunc: true,
+	}},
+	"format": {{
+		Name: "format",
+		Ret:  StringType{},
+		Params: []ExprType{
+			StringType{},
+			AnyType{}, // variable length
 		},
-	},
+		VariableLengthParams: true,
+		IsConstFunc:          true,
+	}},
 	"join": {
 		{
 			Name: "join",
@@ -142,6 +186,7 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 				&ArrayType{Elem: StringType{}},
 				StringType{},
 			},
+			IsConstFunc: true,
 		},
 		// When the second parameter is omitted, values are concatenated with ','.
 		{
@@ -150,6 +195,7 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 			Params: []ExprType{
 				&ArrayType{Elem: StringType{}},
 			},
+			IsConstFunc: true,
 		},
 	},
 	"tojson": {{
@@ -158,6 +204,7 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 		Params: []ExprType{
 			AnyType{},
 		},
+		IsConstFunc: true,
 	}},
 	"fromjson": {{
 		Name: "fromJSON",
@@ -1049,3 +1096,42 @@ func (sema *ExprSemanticsChecker) Check(expr ExprNode) (ExprType, []*ExprError)
 	}
 	return ty, errs
 }
+
+// IsConstant returns the given expression is a constant. For example the following expressions
+// are constants.
+//   - 1 == 2
+//   - (!true && 'foo') || 'bar'
+//   - startsWith('foobar', 'foo')
+//   - format('{} + {} = {}', 1, 2, 3)
+func (sema *ExprSemanticsChecker) IsConstant(expr ExprNode) bool {
+	switch e := expr.(type) {
+	case *NullNode, *BoolNode, *IntNode, *FloatNode, *StringNode:
+		return true
+	case *VariableNode, *ObjectDerefNode, *ArrayDerefNode, *IndexAccessNode:
+		return false
+	case *NotOpNode:
+		return sema.IsConstant(e.Operand)
+	case *CompareOpNode:
+		return sema.IsConstant(e.Left) && sema.IsConstant(e.Right)
+	case *LogicalOpNode:
+		return sema.IsConstant(e.Left) && sema.IsConstant(e.Right)
+	case *FuncCallNode:
+		for _, a := range e.Args {
+			if !sema.IsConstant(a) {
+				return false
+			}
+		}
+		sigs, ok := sema.funcs[strings.ToLower(e.Callee)]
+		if !ok {
+			return false
+		}
+		for _, s := range sigs {
+			if !s.IsConstFunc {
+				return false
+			}
+		}
+		return true
+	default:
+		panic("unreachable")
+	}
+}
