@@ -1743,7 +1743,7 @@ func TestParseFormatSpecifiers(t *testing.T) {
 		},
 		{
 			what: "multiple specifiers",
-			in:   "{0} {1}{2}x{3}}{4}!",
+			in:   "{0} {1}{2}x{3}_{4}!",
 			want: []int{0, 1, 2, 3, 4},
 		},
 		{
@@ -1758,13 +1758,17 @@ func TestParseFormatSpecifiers(t *testing.T) {
 		},
 		{
 			what: "uncontiguous",
-			in:   "{0} {2}foo{5} {1}",
-			want: []int{0, 2, 5, 1},
+			in:   "{0} {2}foo{42} {1}",
+			want: []int{0, 2, 42, 1},
 		},
 		{
 			what: "unclosed",
 			in:   "{12foo",
 		},
+		{
+			what: "missing closing brace",
+			in:   "{0",
+		},
 		{
 			what: "not digit",
 			in:   "{hello}",
@@ -1777,24 +1781,115 @@ func TestParseFormatSpecifiers(t *testing.T) {
 			what: "empty",
 			in:   "{}",
 		},
+		{
+			what: "opening brace only",
+			in:   "{",
+		},
 		{
 			what: "specifier inside specifier",
 			in:   "{1{0}2}",
 			want: []int{0},
 		},
 		{
-			what: "escaped",
+			what: "escaped single",
+			in:   "{{0}}",
+		},
+		{
+			what: "complicated escaped format",
 			in:   "{{hello{{0}{{{{1}world}}",
 		},
 		{
-			what: "after escaped",
+			what: "placeholders inside escape",
+			in:   "{{{0} {1} {2}}}",
+			want: []int{0, 1, 2},
+		},
+		{
+			what: "no extra brace",
+			in:   "{0}",
+			want: []int{0},
+		},
+		{
+			what: "closing brace 1",
+			in:   "{0}}",
+		},
+		{
+			what: "closing brace 2",
+			in:   "{0}}}",
+			want: []int{0},
+		},
+		{
+			what: "closing brace 3",
+			in:   "{0}}}}",
+		},
+		{
+			what: "closing brace 4",
+			in:   "{0}}}}}",
+			want: []int{0},
+		},
+		{
+			what: "closing brace 1 with trailing character",
+			in:   "{0}}x",
+		},
+		{
+			what: "closing brace 2 with trailing character",
+			in:   "{0}}}x",
+			want: []int{0},
+		},
+		{
+			what: "closing brace 3 with trailing character",
+			in:   "{0}}}}x",
+		},
+		{
+			what: "closing brace 4 with trailing character",
+			in:   "{0}}}}}x",
+			want: []int{0},
+		},
+		{
+			what: "opening brace 1",
+			in:   "{{0}",
+		},
+		{
+			what: "opening brace 2",
+			in:   "{{{0}",
+			want: []int{0},
+		},
+		{
+			what: "opening brace 3",
+			in:   "{{{{0}",
+		},
+		{
+			what: "opening brace 4",
 			in:   "{{{{{0}",
 			want: []int{0},
 		},
+		{
+			what: "opening brace after escaped closing brace",
+			in:   "{1}}{2}",
+			want: []int{2},
+		},
+		{
+			what: "escaped opening brace after escaped closing brace",
+			in:   "{1}}{{2}",
+		},
+		{
+			what: "escaped opening brace after closing brace",
+			in:   "{1}{{2}",
+			want: []int{1},
+		},
 		{
 			what: "kuma-",
 			in:   "{・{ᴥ}・}",
 		},
+		{
+			what: "multi byte",
+			in:   "あ{0}い{1}う{2}え{3}お",
+			want: []int{0, 1, 2, 3},
+		},
+		{
+			what: "emoji",
+			in:   "🐶{0}👨‍👩‍👦‍👦{1}🇺🇸{2}🐦‍🔥",
+			want: []int{0, 1, 2},
+		},
 	}
 
 	for _, tc := range tests {
@@ -1812,4 +1907,61 @@ func TestParseFormatSpecifiers(t *testing.T) {
 	}
 }
 
+func TestExprIsConstant(t *testing.T) {
+	tests := []struct {
+		input   string
+		isConst bool
+	}{
+		{"true", true},
+		{"42", true},
+		{"3.14", true},
+		{"null", true},
+		{"'hello'", true},
+		{"foo", false},
+		{"foo.bar", false},
+		{"foo.*", false},
+		{"foo[0]", false},
+		{"!true", true},
+		{"!null", true},
+		{"!foo", false},
+		{"1 == 2", true},
+		{"'foo' != 'bar'", true},
+		{"foo == 2", false},
+		{"1 == foo", false},
+		{"true && 42 || 13", true},
+		{"foo && 42 || 13", false},
+		{"true && foo || 13", false},
+		{"true && 42 || foo", false},
+		{"true && ('foo' == 'bar') && null", true},
+		{"false || (3.14 != null) || !null", true},
+		{"startsWith('foo', 'f')", true},
+		{"startsWith(foo, 'f')", false},
+		{"format('{0}{1}', 1.0, true)", true},
+		{"format('{0}{1}', startsWith('foo', 'f'), 1.0 == !null)", true},
+		{"toJSON(true)", true},
+		{"toJSON(foo)", false},
+		{"success()", false},
+		{"failure()", false},
+		{"hashFiles('foo', 'bar')", false},
+		{"conains(fromJSON('[\"foo\"]'), 'foo')", false},
+		{"unknownFunc(1, 2, 3)", false},
+	}
+
+	for _, tc := range tests {
+		t.Run(tc.input, func(t *testing.T) {
+			p := NewExprParser()
+			e, err := p.Parse(NewExprLexer(tc.input + "}}"))
+			if err != nil {
+				t.Fatalf("Parse error for input %q: %s", tc.input, err)
+			}
+
+			c := NewExprSemanticsChecker(false, nil)
+			b := c.IsConstant(e)
+			if b != tc.isConst {
+				t.Fatalf("wanted %v but got %v for input %q", tc.isConst, b, tc.input)
+			}
+		})
+	}
+}
+
 // vim: nofoldenable
