@@ -211,7 +211,7 @@ func (l *Linter) debug(format string, args ...interface{}) {
 	if l.logLevel < LogLevelDebug {
 		return
 	}
-	format = fmt.Sprintf("[Linter] %s\n", format)
+	format = "[Linter] " + format + "\n"
 	fmt.Fprintf(l.logOut, format, args...)
 }
 
@@ -636,6 +636,7 @@ func (l *Linter) check(
 	}
 
 	slices.SortFunc(all, compareErrors)
+	all = slices.CompactFunc(all, equalsErrors) // Alias may duplicate errors
 
 	if l.logLevel >= LogLevelVerbose {
 		elapsed := time.Since(start)
