@@ -1,8 +1,6 @@
 package actionlint
 
 import (
-	"maps"
-	"slices"
 	"strconv"
 	"strings"
 )
@@ -586,9 +584,7 @@ func (rule *RuleExpression) checkSnapshot(s *Snapshot) {
 	if s == nil {
 		return
 	}
-	// XXX: Available contexts in `jobs.<job_name>.snapshot` is not defined in the document.
-	// https://github.com/github/docs/issues/41255
-	rule.checkIfCondition(s.If, "🐶")
+	rule.checkIfCondition(s.If, "jobs.<job_id>.snapshot.if")
 }
 
 func (rule *RuleExpression) checkWebhookEventFilter(f *WebhookEventFilter) {
@@ -797,13 +793,7 @@ func (rule *RuleExpression) checkSemanticsOfExprNode(expr ExprNode, line, col in
 	if rule.jobsTy != nil {
 		c.UpdateJobs(rule.jobsTy)
 	}
-	if workflowKey == "🐶" {
-		// XXX: This is a special case for `jobs.<job_name>.snapshot`. See `checkSnapshot` method
-		ctx := slices.Sorted(maps.Keys(AllContexts))
-		sp := slices.Sorted(maps.Keys(SpecialFunctionNames))
-		c.SetContextAvailability(ctx)
-		c.SetSpecialFunctionAvailability(sp)
-	} else if workflowKey != "" {
+	if workflowKey != "" {
 		ctx, sp := WorkflowKeyAvailability(workflowKey)
 		if len(ctx) == 0 {
 			rule.Debug("No context availability was found for workflow key %q", workflowKey)
