@@ -11,9 +11,6 @@ const (
 	compatInvalid                   = 0
 	compatUbuntu2204 runnerOSCompat = 1 << iota
 	compatUbuntu2404
-	compatMacOS130
-	compatMacOS130L
-	compatMacOS130XL
 	compatMacOS140
 	compatMacOS140L
 	compatMacOS140XL
@@ -45,7 +42,6 @@ var allGitHubHostedRunnerLabels = []string{
 	"ubuntu-22.04",
 	"ubuntu-22.04-arm",
 	"macos-latest",
-	"macos-latest-xl",
 	"macos-latest-xlarge",
 	"macos-latest-large",
 	"macos-26-xlarge",
@@ -54,14 +50,9 @@ var allGitHubHostedRunnerLabels = []string{
 	"macos-15-xlarge",
 	"macos-15-large",
 	"macos-15",
-	"macos-14-xl",
 	"macos-14-xlarge",
 	"macos-14-large",
 	"macos-14",
-	"macos-13-xl",
-	"macos-13-xlarge",
-	"macos-13-large",
-	"macos-13",
 }
 
 // https://docs.github.com/en/actions/hosting-your-own-runners/using-self-hosted-runners-in-a-workflow#using-default-labels-to-route-jobs
@@ -89,7 +80,6 @@ var defaultRunnerOSCompats = map[string]runnerOSCompat{
 	"ubuntu-24.04-arm":       compatUbuntu2404,
 	"ubuntu-22.04":           compatUbuntu2204,
 	"ubuntu-22.04-arm":       compatUbuntu2204,
-	"macos-latest-xl":        compatMacOS150XL,
 	"macos-latest-xlarge":    compatMacOS150XL,
 	"macos-latest-large":     compatMacOS150L,
 	"macos-latest":           compatMacOS150,
@@ -99,21 +89,16 @@ var defaultRunnerOSCompats = map[string]runnerOSCompat{
 	"macos-15-xlarge":        compatMacOS150XL,
 	"macos-15-large":         compatMacOS150L,
 	"macos-15":               compatMacOS150,
-	"macos-14-xl":            compatMacOS140XL,
 	"macos-14-xlarge":        compatMacOS140XL,
 	"macos-14-large":         compatMacOS140L,
 	"macos-14":               compatMacOS140,
-	"macos-13-xl":            compatMacOS130XL,
-	"macos-13-xlarge":        compatMacOS130XL,
-	"macos-13-large":         compatMacOS130L,
-	"macos-13":               compatMacOS130,
 	"windows-latest":         compatWindows2022,
 	"windows-latest-8-cores": compatWindows2022,
 	"windows-2025":           compatWindows2025,
 	"windows-2022":           compatWindows2022,
 	"windows-11-arm":         compatWindows11Arm,
 	"linux":                  compatUbuntu2404 | compatUbuntu2204, // Note: "linux" does not always indicate Ubuntu. It might be Fedora or Arch or ...
-	"macos":                  compatMacOS260 | compatMacOS260XL | compatMacOS150 | compatMacOS150Intel | compatMacOS150L | compatMacOS150XL | compatMacOS140 | compatMacOS140L | compatMacOS140XL | compatMacOS130 | compatMacOS130L | compatMacOS130XL,
+	"macos":                  compatMacOS260 | compatMacOS260XL | compatMacOS150 | compatMacOS150Intel | compatMacOS150L | compatMacOS150XL | compatMacOS140 | compatMacOS140L | compatMacOS140XL,
 	"windows":                compatWindows2025 | compatWindows2022 | compatWindows11Arm,
 }
 
